==> eam-wshub-proxyclient-11.4-4-sources.jar: net/datastream/schemas/mp_fields/INVOICEVOUCHERLINEID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour INVOICEVOUCHERLINEID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="INVOICEVOUCHERLINEID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}INVOICEID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}INVOICELINENUM" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "INVOICEVOUCHERLINEID_Type", propOrder = {
    "invoiceid",
    "invoicelinenum"
})
public class INVOICEVOUCHERLINEID_Type {

    @XmlElement(name = "INVOICEID", required = true)
    protected INVOICEID_Type invoiceid;
    @XmlElement(name = "INVOICELINENUM")
    protected Long invoicelinenum;

    /**
     * Obtient la valeur de la propriété invoiceid.
     * 
     * @return
     *     possible object is
     *     {@link INVOICEID_Type }
     *     
     */
    public INVOICEID_Type getINVOICEID() {
        return invoiceid;
    }

    /**
     * Définit la valeur de la propriété invoiceid.
     * 
     * @param value
     *     allowed object is
     *     {@link INVOICEID_Type }
     *     
     */
    public void setINVOICEID(INVOICEID_Type value) {
        this.invoiceid = value;
    }

    /**
     * Obtient la valeur de la propriété invoicelinenum.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getINVOICELINENUM() {
        return invoicelinenum;
    }

    /**
     * Définit la valeur de la propriété invoicelinenum.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setINVOICELINENUM(Long value) {
        this.invoicelinenum = value;
    }

}

==> eam-wshub-proxyclient-11.7-4-sources.jar: net/datastream/schemas/mp_fields/INVOICEVOUCHERLINEID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for INVOICEVOUCHERLINEID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="INVOICEVOUCHERLINEID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}INVOICEID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}INVOICELINENUM" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "INVOICEVOUCHERLINEID_Type", propOrder = {
    "invoiceid",
    "invoicelinenum"
})
public class INVOICEVOUCHERLINEID_Type {

    @XmlElement(name = "INVOICEID", required = true)
    protected INVOICEID_Type invoiceid;
    @XmlElement(name = "INVOICELINENUM")
    protected Long invoicelinenum;

    /**
     * Gets the value of the invoiceid property.
     * 
     * @return
     *     possible object is
     *     {@link INVOICEID_Type }
     *     
     */
    public INVOICEID_Type getINVOICEID() {
        return invoiceid;
    }

    /**
     * Sets the value of the invoiceid property.
     * 
     * @param value
     *     allowed object is
     *     {@link INVOICEID_Type }
     *     
     */
    public void setINVOICEID(INVOICEID_Type value) {
        this.invoiceid = value;
    }

    /**
     * Gets the value of the invoicelinenum property.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getINVOICELINENUM() {
        return invoicelinenum;
    }

    /**
     * Sets the value of the invoicelinenum property.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setINVOICELINENUM(Long value) {
        this.invoicelinenum = value;
    }

}
